(function (drupalSettings) {

  'use strict';

  const GridLoader = VueSpinner.GridLoader;
  const url = drupalSettings['url'];
  const units_of_measurement = drupalSettings['units_of_measurement'];
  // Translated names of weather characteristics.
  const weather_characteristics = drupalSettings['weather_characteristics'];

  const app = Vue.createApp({
    data: () => ({
      city: null,
      country: null,
      feels_like: null,
      description: null,
      wind_speed: null,
      temperature: null,
      pressure: null,
      humidity: null,
      icon_url: null,
      reconnection_limit: 10,
      reconnection_attempts: 0,
      service_unavailable: false,
      // Display the loader if connection failed before next reconnection.
      display_loader: false,
    }),

    components:{
      GridLoader
    },

    methods: {
      getWeather(){
        this.service_unavailable = false;

        axios
        .get(url)
        .then(response => this.prepareData(response.data))
        .catch(error => this.errorHandler(error));
      },

      prepareData(data){
        this.display_loader = false;
        this.reconnection_attempts = 0;
        // If a country name is not available, then display a country code.
        this.country = drupalSettings['country_name'] ? drupalSettings['country_name'] : data.sys.country;
        this.city = data.name;
        this.icon_url = 'http://openweathermap.org/img/w/' + data.weather[0].icon + '.png';
        this.feels_like = weather_characteristics['feels_like'] + ': ' + data.main.feels_like;
        const description = data.weather[0].description;
        // Capitalize the first letter.
        this.description = description.charAt(0).toUpperCase() + description.slice(1);
        this.wind_speed = weather_characteristics['wind_speed'] + ': ' + data.wind.speed;
        this.temperature = weather_characteristics['temperature'] + ': ' + data.main.temp;
        this.pressure = weather_characteristics['pressure'] + ': ' + data.main.pressure;
        this.humidity = weather_characteristics['humidity'] + ': ' + data.main.humidity;
        this.addUnitsSuffixes();

        if (drupalSettings['update_periodically']) {
          // Update the weather data at a specified time interval.
          setInterval(() => this.getWeather(), drupalSettings['update_interval']);
        }
      },

      errorHandler(error){
        if (this.reconnection_attempts < this.reconnection_limit) {
          this.display_loader = true;
          this.getWeather();
          this.reconnection_attempts++;
        }
        else {
          this.display_loader = false;
          this.reconnection_attempts = 0;
          this.service_unavailable = true;
        }
      },

      addUnitsSuffixes(){
        // Add the degree symbol.
        this.temperature += '\xB0';
        this.feels_like += '\xB0';

        switch (units_of_measurement) {
          case 'standard':
            this.temperature += 'K';
            this.feels_like += 'K';
            break;

          case 'metric':
            this.temperature += 'C';
            this.feels_like += 'C';
            break;

          case 'imperial':
            this.temperature += 'F';
            this.feels_like += 'F';
            break;
        }
      }
    },

    created() {
      this.getWeather();
    }
  });

  app.mount('#weather');

})(drupalSettings);
